@@ -1,6 +1,6 @@
 from typing import Optional
 
-from figcli.models.defaults.defaults import CLIDefaults
+from figcli.models.defaults.defaults import CLIDefaults, CliCommand
 from figgy.models.run_env import RunEnv
 from figcli.models.role import Role
 from figcli.commands.command_context import CommandContext
@@ -11,7 +11,7 @@ class IAMContext(CommandContext):
     All `iam` resource commands require this context for general use. Config commands operate differently based on
     Role and RunEnv
     """
-    def __init__(self, run_env: RunEnv, role: Role, colors_enabled: bool, resource: frozenset,
+    def __init__(self, run_env: RunEnv, role: Role, colors_enabled: bool, resource: CliCommand,
                  defaults: Optional[CLIDefaults]):
         super().__init__(run_env, resource, defaults=defaults)
         self.role: Role = role
